komodo_coins library
Komodo Coins Library
High-level library that provides access to Komodo Platform coin data and configurations using strategy patterns for loading and updating coin configurations.
Classes
- AssetFilterStrategy
- Strategy interface for filtering assets based on coin configuration.
- AssetsUpdateManager
- Contract for interacting with Komodo coins configuration and updates.
- EvmAssetFilterStrategy
- Filters assets that are EVM-based tokens. This includes various EVM-compatible chains like Ethereum, Binance, etc. This strategy is necessary for external wallets like Metamask or WalletConnect.
- KomodoAssetsUpdateManager
- A high-level library that provides a simple way to access Komodo Platform coin data and seed nodes.
- NoAssetFilterStrategy
- Default strategy that includes all assets.
- StartupCoinsProvider
-
Provides a minimal, read-only way to obtain the raw coins list needed to
start mm2/KDF, without instantiating update managers or starting background
processes. It wires a
CoinConfigManagerwith only read-capable sources (storage + asset bundle), initializes it, extracts configs, and disposes. - TrezorAssetFilterStrategy
- Filters assets that are not currently supported on Trezor. This includes assets that are not UTXO-based or EVM-based tokens. ETH, AVAX, BNB, FTM, etc. are excluded as they currently fail to activate on Trezor. ERC20, Arbitrum, and MATIC explicitly do not support Trezor via KDF at this time, so they are also excluded.
- UtxoAssetFilterStrategy
- Filters out assets that are not UTXO-based chains.